@@ -173,6 +173,32 @@ native_tests() {
 	fi
 }
 
+# Test the library built with FREESTANDING=1.
+freestanding_tests() {
+	test_group_included freestanding || return 0
+
+	WRAPPER= native_build_and_test FREESTANDING=1
+	if nm libdeflate.so | grep -q ' U '; then
+		echo 1>&2 "Freestanding lib links to external functions!:"
+		nm libdeflate.so | grep ' U '
+		return 1
+	fi
+	if ldd libdeflate.so | grep -q -v '\<statically linked\>'; then
+		echo 1>&2 "Freestanding lib links to external libraries!:"
+		ldd libdeflate.so
+		return 1
+	fi
+
+	if have_valgrind; then
+		WRAPPER="$VALGRIND" native_build_and_test FREESTANDING=1
+	fi
+
+	if have_ubsan; then
+		WRAPPER= native_build_and_test FREESTANDING=1 \
+			CC=clang CFLAGS="$SANITIZE_CFLAGS"
+	fi
+}
+
 ###############################################################################
 
 checksum_benchmarks() {
@@ -361,6 +387,7 @@ log "	SMOKEDATA=$SMOKEDATA"
 log "	NDKDIR=$NDKDIR"
 
 native_tests
+freestanding_tests
 checksum_benchmarks
 android_tests
 mips_tests
